# ANurbs

A simple NURBS library for _Isogeometric B-Rep Analysis_ (_IBRA_)

[![Build Status](https://github.com/oberbichler/ANurbs/workflows/Python%20package/badge.svg?branch=master)](https://github.com/oberbichler/ANurbs/actions) [![Codacy grade](https://img.shields.io/codacy/grade/a2bc0400ebef41b799e88a15263b2c12/master)](https://app.codacy.com/manual/oberbichler/ANurbs) [![PyPI](https://img.shields.io/pypi/v/anurbs)](https://pypi.org/project/anurbs)

## Installation

```
pip install anurbs
```

## Reference

If you use ANurbs, please refer to the official GitHub repository:

```
@misc{ANurbs,
  author = "Thomas Oberbichler",
  title = "ANurbs",
  howpublished = "\url{http://github.com/oberbichler/ANurbs}",
}
```
